# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-11-14 12:17
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='Comment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, db_index=True, verbose_name='created at')),
                ('changed_at', models.DateTimeField(auto_now=True, db_index=True, verbose_name='changed at')),
                ('comment', models.TextField(verbose_name='comment')),
                ('object_pk', models.TextField(db_index=True)),
                ('author', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL,
                                             verbose_name='author')),
                ('content_type',
                 models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType')),
            ],
            options={
                'verbose_name': 'comment',
                'verbose_name_plural': 'comments',
                'ordering': ('-created_at',),
            },
        ),
    ]



from django.conf import settings
from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.db import models
from django.utils.translation import ugettext_lazy

from chamber.models import SmartModel


class CommentQuerySet(models.QuerySet):

    def filter_for_object(self, obj):
        return self.filter(
            content_type=ContentType.objects.get_for_model(obj),
            object_pk=obj.id
        )


class Comment(SmartModel):

    objects = CommentQuerySet.as_manager()

    author = models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name=ugettext_lazy('author'), on_delete=models.CASCADE,
                               null=True, blank=True, db_index=True)
    comment = models.TextField(verbose_name=ugettext_lazy('comment'), null=False, blank=False)
    content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
    object_pk = models.TextField(db_index=True)
    content_object = GenericForeignKey('content_type', 'object_pk')
    content_object.verbose_name = ugettext_lazy('object')

    class Meta:
        verbose_name = ugettext_lazy('comment')
        verbose_name_plural = ugettext_lazy('comments')
        ordering = ('-created_at',)



from django import forms
from django.contrib.contenttypes.models import ContentType
from django.utils.translation import ugettext_lazy

from is_core.generic_views.inlines.inline_objects_views import TabularInlineObjectsView

from user_comments.models import Comment

from is_core.forms.models import SmartModelForm
from is_core.generic_views.detail_views import DjangoDetailFormView


class CommentUiForm(SmartModelForm):

    comment = forms.CharField(label=ugettext_lazy('add comment'), required=False, widget=forms.Textarea())

    def _post_save(self, obj):
        super()._post_save(obj)
        comment = self.cleaned_data.get('comment')
        if comment:
            Comment.objects.create(
                content_object=obj,
                author=self._request.user,
                comment=comment
            )


class CommentObjectsView(TabularInlineObjectsView):

    model = Comment
    fields = (
        ('author', ugettext_lazy('Author')),
        ('created_at', ugettext_lazy('Created at')),
        ('comment', ugettext_lazy('Comment')),
    )

    def get_objects(self):
        return self.model.objects.filter(
            content_type=ContentType.objects.get_for_model(self.parent_instance),
            object_pk=self.parent_instance.pk
        )


class DetailCommentFormView(DjangoDetailFormView):

    def get_readonly_fields(self):
        return (
            tuple(field for field in super().get_fields() if field != 'comment')
            if self.core.get_can_update_only_comment(self.request, obj=self.get_obj())
            else super().get_readonly_fields()
        )


class CommentCoreMixin:

    form_class = CommentUiForm
    ui_detail_view = DetailCommentFormView

    notes_fieldset = (
        (ugettext_lazy('Comments'), {
            'fieldsets': (
                (None, {'inline_view': CommentObjectsView}),
                (None, {'fields': ('comment',)}),
            )
        }),
    )

    def get_can_update_only_comment(self, request, obj=None):
        return hasattr(self, 'can_update_only_comment') and self.can_update_only_comment



# Generated by Django 3.1 on 2021-11-24 07:59

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('user_comments', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='comment',
            name='author',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                    to=settings.AUTH_USER_MODEL),
        ),
    ]



from setuptools import setup, find_packages

setup(
    name='skip-django-user-comments',
    version='0.0.7.1',
    description='Library for adding comments of users related with object',
    author='Lubos Matl',
    author_email='matllubos@gmail.com',
    packages=find_packages(),
    install_requires=[
        'skip-django-chamber>=0.6.16.3',
    ],
    include_package_data=True,
    zip_safe=False,
)
